ListKeysRequest

Struct ListKeysRequest 

pub struct ListKeysRequest {
    pub api_id: String,
    pub owner_id: Option<String>,
    pub limit: Option<usize>,
    pub cursor: Option<String>,
    pub revalidate_cache: Option<bool>,
}
An outgoing paginated list keys request.

Fields

api_id: String

The id of the api to list keys for.

owner_id: Option<String>

The optional owner id used to filter keys by owner.

limit: Option<usize>

The optional number of keys to return, up to 100.

cursor: Option<String>

The pagination cursor indicating the last key that was returned.

revalidate_cache: Option<bool>

Whether to revalidate the cache for this request.

Implementations

Source

impl ListKeysRequest

pub fn new<T: Into<String>>(api_id: T) -> Self

Creates a new list keys request.

Arguments
  • api_id: The id of the api to list keys for.
Returns

The new list keys request.

Example
let r = ListKeysRequest::new("test");

assert_eq!(r.api_id, String::from("test"));
assert_eq!(r.limit, None);
assert_eq!(r.cursor, None);
assert_eq!(r.owner_id, None);
assert_eq!(r.revalidate_cache, None);
pub fn set_limit(self, limit: usize) -> Self

Sets the limit for the request.

Arguments
  • limit: The limit to set.
Returns

Self for chained calls.

Example
let r = ListKeysRequest::new("test").set_limit(50);

assert_eq!(r.limit.unwrap(), 50);
pub fn set_cursor<T: Into<String>>(self, cursor: T) -> Self

Sets the pagination offset for the request.

Arguments
  • cursor: The pagination offset cursor to set.
Returns

Self for chained calls.

Example
let r = ListKeysRequest::new("test").set_cursor("abcabc");

assert_eq!(r.cursor.unwrap(), String::from("abcabc"));
pub fn set_owner_id<T: Into<String>>(self, owner_id: T) -> Self

Sets the owner id for filtering the listed keys by owner.

Arguments
  • owner_id: The owner id to set.
Returns

Self for chained calls.

Example
let r = ListKeysRequest::new("test").set_owner_id("WilfredAlmeida");

assert_eq!(r.owner_id.unwrap(), String::from("WilfredAlmeida"));
pub fn set_revalidate_cache(self, revalidate_cache: bool) -> Self

Sets the flag for revalidating the cache for this request.

Arguments
  • revalidate_cache: Whether to revalidate the cache with this request.
Returns

Self for chained calls.

Example
let r = ListKeysRequest::new("test").set_revalidate_cache(true);

assert_eq!(r.revalidate_cache.unwrap(), true);