pub struct ListKeysRequest {
pub api_id: String,
pub owner_id: Option<String>,
pub limit: Option<usize>,
pub cursor: Option<String>,
pub revalidate_cache: Option<bool>,
}Expand description
An outgoing paginated list keys request.
Fields
api_id: StringThe id of the api to list keys for.
owner_id: Option<String>The optional owner id used to filter keys by owner.
limit: Option<usize>The optional number of keys to return, up to 100.
cursor: Option<String>The pagination cursor indicating the last key that was returned.
revalidate_cache: Option<bool>Whether to revalidate the cache for this request.
Implementations
Sourceimpl ListKeysRequest
impl ListKeysRequest
Sourcepub fn new<T: Into<String>>(api_id: T) -> Self
pub fn new<T: Into<String>>(api_id: T) -> Self
Creates a new list keys request.
Arguments
api_id: The id of the api to list keys for.
Returns
The new list keys request.
Example
let r = ListKeysRequest::new("test");
assert_eq!(r.api_id, String::from("test"));
assert_eq!(r.limit, None);
assert_eq!(r.cursor, None);
assert_eq!(r.owner_id, None);
assert_eq!(r.revalidate_cache, None);Sourcepub fn set_cursor<T: Into<String>>(self, cursor: T) -> Self
pub fn set_cursor<T: Into<String>>(self, cursor: T) -> Self
Sourcepub fn set_owner_id<T: Into<String>>(self, owner_id: T) -> Self
pub fn set_owner_id<T: Into<String>>(self, owner_id: T) -> Self
Sourcepub fn set_revalidate_cache(self, revalidate_cache: bool) -> Self
pub fn set_revalidate_cache(self, revalidate_cache: bool) -> Self